==> croud-0.8.1.tar.gz: croud-0.8.1/croud/projects/users/commands.py <==
# Licensed to CRATE Technology GmbH ("Crate") under one or more contributor
# license agreements.  See the NOTICE file distributed with this work for
# additional information regarding copyright ownership.  Crate licenses
# this file to you under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.  You may
# obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations
# under the License.
#
# However, if you have executed another commercial license agreement
# with Crate these terms will supersede the license and you may use the
# software solely pursuant to the terms of the relevant commercial agreement.

from argparse import Namespace

from croud.gql import Query, print_query


def project_user_add(args: Namespace) -> None:
    """
    Adds a user to a project.
    """

    _query = f"""
    mutation {{
        addUserToProject(input: {{
            projectId: "{args.project_id}",
            user: "{args.user}"
        }}) {{
            success
        }}
    }}
    """

    query = Query(_query, args)
    query.execute()
    print_query(query, "addUserToProject", "Successfully added user to project.")


def project_user_remove(args: Namespace) -> None:
    """
    Removes a user to a project.
    """

    _query = f"""
    mutation {{
        removeUserFromProject(input: {{
            projectId: "{args.project_id}",
            user: "{args.user}"
        }}) {{
            success
        }}
    }}
    """

    query = Query(_query, args)
    query.execute()
    print_query(
        query, "removeUserFromProject", "Successfully removed user from project."
    )

==> croud-0.15.1.tar.gz: croud-0.15.1/croud/projects/users/commands.py <==
# Licensed to CRATE Technology GmbH ("Crate") under one or more contributor
# license agreements.  See the NOTICE file distributed with this work for
# additional information regarding copyright ownership.  Crate licenses
# this file to you under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.  You may
# obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations
# under the License.
#
# However, if you have executed another commercial license agreement
# with Crate these terms will supersede the license and you may use the
# software solely pursuant to the terms of the relevant commercial agreement.

from argparse import Namespace

from croud.rest import Client
from croud.session import RequestMethod


def project_users_add(args: Namespace) -> None:
    """
    Adds a user to a project.
    """

    client = Client.from_args(args)

    client.send(
        RequestMethod.POST,
        f"/api/v2/projects/{args.project_id}/users/",
        body={"user": args.user, "role_fqn": args.role},
    )
    client.print(keys=["user_id", "project_id", "role_fqn"])


def project_users_remove(args: Namespace) -> None:
    """
    Removes a user from a project.
    """

    client = Client.from_args(args)
    client.send(
        RequestMethod.DELETE, f"/api/v2/projects/{args.project_id}/users/{args.user}/"
    )
    client.print(success_message="Successfully removed user from project.")
